@@ -18,8 +18,9 @@ setattr(PandasObject, "ta", property(lambda self: _TA(self)))
 # auto import pandas ml utils
 try:
     pandas_ml_utils = importlib.import_module("pandas_ml_utils")
-except:
     _log.warning(f"automatically imported pandas_ml_utils {pandas_ml_utils.__version__}")
+except:
+    _log.error(f"pandas_ml_utils module not available but needed!")
 
 # auto import pandas ml quant data prviders
 try:
@@ -28,3 +29,10 @@ try:
 except:
     _log.warning("pandas_ml_quant_data_provider module not avialable!")
 
+# auto import pandas quant reinforcement learning
+try:
+    pandas_ml_quant_rl = importlib.import_module("pandas_ml_quant_rl")
+    _log.warning(f"automatically imported pandas_ml_quant_rl {pandas_ml_quant_rl.__version__}")
+except:
+    pass
+
